@@ -4,17 +4,16 @@ import time
 from argparse import ArgumentParser, Namespace
 
 import deltachat.const
-from deltachat import Account
 from deltachat.events import FFIEventLogger
 from deltachat.tracker import ConfigureTracker
 
+from . import __version__
+from .account import Account
+from .application import Application
 from .event import AccountPlugin
 from .oauth2 import get_authz_code, is_oauth2
-from .ui import CursedDelta
 from .util import (
-    APP_NAME,
     capture_keyboard_interrupt,
-    create_message,
     fail,
     get_configuration,
     get_keymap,
@@ -45,11 +44,12 @@ def main() -> None:
 
 def get_parser(cfg: dict) -> ArgumentParser:
     parser = ArgumentParser(prog="curseddelta")
+    parser.add_argument("-v", "--version", action="version", version=__version__)
     parser.add_argument(
         "--db",
         action="store",
-        help="database file",
-        default=cfg["general"]["account_path"],
+        help="account's database file",
+        default=cfg["global"]["account_path"],
     )
     parser.add_argument(
         "--show-ffi", action="store_true", help="show low level ffi events"
@@ -166,7 +166,7 @@ def send_cmd(args: Namespace) -> None:
 
         print(f"Sending message to {chat.get_name()!r}")
         msg = chat.send_msg(
-            create_message(args.acct, text=args.text, filename=args.filename)
+            args.acct.create_message(text=args.text, filename=args.filename)
         )
         while not msg.is_out_delivered():
             time.sleep(0.1)
@@ -187,4 +187,5 @@ def start_ui(args: Namespace) -> None:
     args.acct.add_account_plugin(plugin)
 
     with online_account(args.acct):
-        CursedDelta(args.cfg, get_keymap(), get_theme(), APP_NAME, plugin)
+        app = Application(args.cfg, get_keymap(), get_theme(), plugin)
+        app.run()
